#[non_exhaustive]pub struct Config {
pub credentials: CredentialSource,
pub endpoint: Option<String>,
pub region: String,
pub retry: RetryPolicy,
pub transfer: TransferConfig,
/* private fields */
}Expand description
Top-level client configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.credentials: CredentialSourceHow to obtain AWS credentials.
endpoint: Option<String>Custom endpoint for S3-compatible backends (MinIO, R2, GCS).
When None, uses the default AWS endpoint.
region: StringAWS region (e.g. us-east-1).
retry: RetryPolicyRetry behaviour.
transfer: TransferConfigTransfer tuning knobs.
Implementations
Sourceimpl Config
impl Config
Sourcepub fn endpoint_url(&self) -> &str
pub fn endpoint_url(&self) -> &str
Resolved S3 endpoint URL.
Sourcepub fn new(region: impl Into<String>, credentials: CredentialSource) -> Self
pub fn new(region: impl Into<String>, credentials: CredentialSource) -> Self
Create a new config with the given region and credentials.
Uses default transfer and retry settings. Override fields after construction if needed.
Sourcepub fn with_endpoint(
region: impl Into<String>,
credentials: CredentialSource,
endpoint: String,
) -> Self
pub fn with_endpoint( region: impl Into<String>, credentials: CredentialSource, endpoint: String, ) -> Self
Create a new config with a custom endpoint for S3-compatible backends.